#
# spec file for package kcm-fcitx
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define		pkgname	fcitx-config-kde4

Name:           kcm-fcitx
Version:        0.4.3
Release:        6.3
Summary:        KDE control module for Fcitx
License:        GPL-2.0+
Group:          System/I18n/Chinese
Url:            http://github.com/fcitx/kcm-fcitx
Source:         http://download.fcitx-im.org/kcm-fcitx/%{name}-%{version}.tar.xz
Source1:        input-keyboard.svg
Obsoletes:      %{name} < 0.2.0
Provides:       %{name} = %{version}
BuildRequires:  fcitx-devel
BuildRequires:  libkde4-devel
BuildRequires:  rsvg-view
%if 0%{?suse_version} <= 1140 
BuildRequires:  libunique-devel
%else
BuildRequires:  libunique1-devel
%endif
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  xz
Requires:       fcitx-kcm-icons = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
KDE control module for Fcitx. 

You can config fcitx through "Configue Desktop" - "Locale" - Fcitx now.

%package -n %{pkgname}
Summary:        KDE control module for Fcitx
Group:          System/I18n/Chinese
%kde4_runtime_requires
%fcitx_requires
Provides:       locale(kdebase4:ko;zh_CN;zh_SG)
Supplements:    packageand(fcitx:kdebase4)	

%description -n %{pkgname}
KDE control module for Fcitx.

You can config fcitx through "Configure Desktop" - "Locale" - Fcitx now.

%package -n %{pkgname}-icons
Summary:        Keyboard icons for %{pkgname}
Group:          System/I18n/Chinese
Requires:       %{pkgname} = %{version}
Provides:       fcitx-kcm-icons = %{version}
Conflicts:      otherproviders(fcitx-kcm-icons)
Supplements:    packageand(%{pkgname}:kdebase4-workspace-branding)
BuildArch:      noarch

%description -n %{pkgname}-icons
This package provides systemsetting icons for fcitx in kdebase4-workspace.

%prep
%setup -q -n %{name}-%{version}

%build
%{__mkdir} -pv build
pushd build

cmake .. -DCMAKE_INSTALL_PREFIX=%{_prefix} -DLIB_INSTALL_DIR=%{_libdir}

make

%install
pushd build

make DESTDIR=%{buildroot} install

popd

sed -i "s/Categories=Qt;KDE;Utility/Categories=Qt;KDE;Utility;DesktopUtility;/" %{buildroot}%{_datadir}/applications/kde4/kbd-layout-viewer.desktop

ICONSIZE="16 22 32 48 64 128 256"
for i in $ICONSIZE; do
    mkdir -pv %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/devices/
    rsvg-convert -h $i -w $i %{SOURCE1} -o %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/devices/input-keyboard.png
done

%find_lang kcm_fcitx

%kde_post_install

%post -n %{pkgname} -p /sbin/ldconfig

%postun -n %{pkgname} -p /sbin/ldconfig

%files -n %{pkgname} -f kcm_fcitx.lang
%defattr(-,root,root,-)
%{_bindir}/kbd-layout-viewer
%{_libdir}/kde4/kcm_fcitx.so
%{_datadir}/kde4/config/fcitx-skin.knsrc
%{_datadir}/kde4/services/kcm_fcitx.desktop
%{_datadir}/applications/kde4/kbd-layout-viewer.desktop

%files -n %{pkgname}-icons
%defattr(-,root,root,-)
%{_datadir}/icons/hicolor/*/devices/input-keyboard.png

%changelog
* Fri Jun  5 2015 i@marguerite.su
- split a new subpackage: fcitx-config-kde4-icons
  * avoid file conflicts when fcitx-config-kde5 is also installed
  * icons may be different later, but for now they're the same
* Mon Jul  1 2013 i@marguerite.su
- update version 0.4.3
  * Use new fcitx-qt widget to grab modifier only key.
  * Translation Update
* Sat Jan 26 2013 i@marguerite.su
- update version 0.4.2
  * Add support for new custom configuration ui.
- kcm-fcitx-0.4.2-compat-qt474.patch
  * fix build with qt 4.7.4 under 12.1 and below.
  * remove next release
* Sat Sep 15 2012 i@marguerite.su
- update version 0.4.1
  * Add support for hidden options
  * Simplify access to current UI setting
* Sat Jul 21 2012 i@marguerite.su
- update version 0.4.0
  * new implementation for key conversion
  * add support for change “default layout”
* Mon Jun 25 2012 i@marguerite.su
- fix fedora builds.
* Thu Jun  7 2012 i@marguerite.su
- remove fix shebang line from spec file.
  * now it has no shebang, this will remove good code
    thus cause no configuration page under system settings - locale.
* Mon Jun  4 2012 i@marguerite.su
- update version 0.3.4
  * configure input method from input method page
* Mon May 28 2012 i@marguerite.su
- bring it into DVD.
* Sun May  6 2012 i@marguerite.su
- update to 0.3.3
  * add super support
  * workaround a potential freeze bug
* Sun Apr  8 2012 i@marguerite.su
- update to 0.3.2
  * Add more X key to Qt key conversion.
* Fri Mar  9 2012 hillwood@linuxfans.org
- update to 0.3.1
  sync with head
* Wed Feb 29 2012 i@marguerite.su
- set _service disabled. update source from git.
* Thu Jan 26 2012 i@marguerite.su
- fix shebang warning
* Thu Jan 26 2012 i@marguerite.su
- update source from git. version 0.4.0
* Mon Oct  3 2011 stecue@gmail.com
- Change the package name to fcitx-config-kde4 to avoid
  confusing.
* Sun Oct  2 2011 stecue@gmail.com
- upstream version 0.2.1
  * works with fcitx-4.1.2
* Fri Sep  9 2011 stecue@gmail.com
- Initial build. Version 0.1.1
